package VMOMI::CannotUseNetworkReason;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
